import { Component } from '@angular/core';
import { FormControl, FormGroup, Validators } from '@angular/forms';
import { SecurityService } from '../../services/security.service';
import { SecurityCredentials } from '../../models/security-credentials.interface';
import { SecurityResponse } from '../../models/security-response.interface';
import { Router } from '@angular/router';

@Component({
  selector: 'app-sign-in',
  templateUrl: './sign-in.component.html',
  styleUrls: ['./sign-in.component.css']
})
export class SignInComponent {

  public lenguage: string = 'es';
  public lenguages: any[] = [
    {
      value: 'es',
      text: 'Español'
    },
    {
      value: 'en',
      text: 'English'
    }
  ];

  public text: any = {
    es: {
      email: 'Usuario o email',
      password: 'Contraseña',
      button: 'Iniciar sesión'
    },
    en: {
      email: 'Username or email',
      password: 'Password',
      button: 'Sign in'
    }
  }

  constructor(private securityService: SecurityService,
    private router: Router) {}

  public signInForm: FormGroup = new FormGroup({
    email: new FormControl<string | null>(null, [Validators.required, Validators.minLength(3)]),
    password: new FormControl<string | null>(null, [Validators.required, Validators.minLength(3)])
  });

  public showError: boolean = false;
  public securityResponse: SecurityResponse | null = null;

  changeLenguage(lenguage: string) {
    this.lenguage = lenguage;
  }

  onSignIn(): void {
    this.signInForm.markAllAsTouched();
    if (this.signInForm.valid) {
      const credentials: SecurityCredentials = this.signInForm.value;
      this.securityService.login(credentials)
        .subscribe(securityResponse => {
          switch(securityResponse.user.role) {
            case 'supervisor':
              this.router.navigate(['/supervisors']);
              break;
            case 'agent':
              this.router.navigate(['/agents']);
              break;
            case 'passenger':
              this.router.navigate(['/passengers']);
              break;
          }
        }, error => this.showError = true);
    } else this.showError = true;

  }
}
